@@ -8,20 +8,13 @@ logger = logging.getLogger(__name__)
 
 
 class Edited_byQuerySet(AuditQuerySet):
-    def delete(self):
-        return super().delete()
-
-    def create(self, **kwargs):
-        return super().create(**kwargs)
-
-    def filter(self, *args, **kwargs):
-        return super().filter(*args, **kwargs)
+    pass
 
 
 class Edited_byManager(AuditManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record ) :
         res = {
             'id': record.id,
             'editing': record.editing,
